@@ -3,40 +3,41 @@
 
 extern crate test;
 
-use crossbeam_channel::unbounded;
-use log::*;
-use rand::{thread_rng, Rng};
-use rayon::prelude::*;
-use solana_core::banking_stage::{BankingStage, BankingStageStats};
-use solana_gossip::cluster_info::ClusterInfo;
-use solana_gossip::cluster_info::Node;
-use solana_ledger::blockstore_processor::process_entries;
-use solana_ledger::entry::{next_hash, Entry};
-use solana_ledger::genesis_utils::{create_genesis_config, GenesisConfigInfo};
-use solana_ledger::{blockstore::Blockstore, get_tmp_ledger_path};
-use solana_perf::packet::to_packets_chunked;
-use solana_perf::test_tx::test_tx;
-use solana_poh::poh_recorder::{create_test_recorder, WorkingBankEntry};
-use solana_runtime::bank::Bank;
-use solana_runtime::cost_model::CostModel;
-use solana_sdk::genesis_config::GenesisConfig;
-use solana_sdk::hash::Hash;
-use solana_sdk::message::Message;
-use solana_sdk::pubkey;
-use solana_sdk::signature::Keypair;
-use solana_sdk::signature::Signature;
-use solana_sdk::signature::Signer;
-use solana_sdk::system_instruction;
-use solana_sdk::system_transaction;
-use solana_sdk::timing::{duration_as_us, timestamp};
-use solana_sdk::transaction::Transaction;
-use solana_streamer::socket::SocketAddrSpace;
-use std::collections::VecDeque;
-use std::sync::atomic::Ordering;
-use std::sync::mpsc::Receiver;
-use std::sync::{Arc, RwLock};
-use std::time::{Duration, Instant};
-use test::Bencher;
+use {
+    crossbeam_channel::unbounded,
+    log::*,
+    rand::{thread_rng, Rng},
+    rayon::prelude::*,
+    solana_core::banking_stage::{BankingStage, BankingStageStats},
+    solana_gossip::cluster_info::{ClusterInfo, Node},
+    solana_ledger::{
+        blockstore::Blockstore,
+        blockstore_processor::process_entries,
+        entry::{next_hash, Entry},
+        genesis_utils::{create_genesis_config, GenesisConfigInfo},
+        get_tmp_ledger_path,
+    },
+    solana_perf::{packet::to_packets_chunked, test_tx::test_tx},
+    solana_poh::poh_recorder::{create_test_recorder, WorkingBankEntry},
+    solana_runtime::{bank::Bank, cost_model::CostModel},
+    solana_sdk::{
+        genesis_config::GenesisConfig,
+        hash::Hash,
+        message::Message,
+        pubkey,
+        signature::{Keypair, Signature, Signer},
+        system_instruction, system_transaction,
+        timing::{duration_as_us, timestamp},
+        transaction::Transaction,
+    },
+    solana_streamer::socket::SocketAddrSpace,
+    std::{
+        collections::VecDeque,
+        sync::{atomic::Ordering, mpsc::Receiver, Arc, RwLock},
+        time::{Duration, Instant},
+    },
+    test::Bencher,
+};
 
 fn check_txs(receiver: &Arc<Receiver<WorkingBankEntry>>, ref_tx_count: usize) {
     let mut total = 0;
