@@ -1,21 +1,24 @@
 //! The `shred_fetch_stage` pulls shreds from UDP sockets and sends it to a channel.
 
-use crate::packet_hasher::PacketHasher;
-use lru::LruCache;
-use solana_ledger::shred::{get_shred_slot_index_type, ShredFetchStats};
-use solana_perf::cuda_runtime::PinnedVec;
-use solana_perf::packet::{Packet, PacketsRecycler};
-use solana_perf::recycler::Recycler;
-use solana_runtime::bank_forks::BankForks;
-use solana_sdk::clock::{Slot, DEFAULT_MS_PER_SLOT};
-use solana_streamer::streamer::{self, PacketReceiver, PacketSender};
-use std::net::UdpSocket;
-use std::sync::atomic::AtomicBool;
-use std::sync::mpsc::channel;
-use std::sync::Arc;
-use std::sync::RwLock;
-use std::thread::{self, Builder, JoinHandle};
-use std::time::Instant;
+use {
+    crate::packet_hasher::PacketHasher,
+    lru::LruCache,
+    solana_ledger::shred::{get_shred_slot_index_type, ShredFetchStats},
+    solana_perf::{
+        cuda_runtime::PinnedVec,
+        packet::{Packet, PacketsRecycler},
+        recycler::Recycler,
+    },
+    solana_runtime::bank_forks::BankForks,
+    solana_sdk::clock::{Slot, DEFAULT_MS_PER_SLOT},
+    solana_streamer::streamer::{self, PacketReceiver, PacketSender},
+    std::{
+        net::UdpSocket,
+        sync::{atomic::AtomicBool, mpsc::channel, Arc, RwLock},
+        thread::{self, Builder, JoinHandle},
+        time::Instant,
+    },
+};
 
 const DEFAULT_LRU_SIZE: usize = 10_000;
 pub type ShredsReceived = LruCache<u64, ()>;
@@ -223,9 +226,10 @@ impl ShredFetchStage {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
-    use solana_ledger::blockstore::MAX_DATA_SHREDS_PER_SLOT;
-    use solana_ledger::shred::Shred;
+    use {
+        super::*,
+        solana_ledger::{blockstore::MAX_DATA_SHREDS_PER_SLOT, shred::Shred},
+    };
 
     #[test]
     fn test_data_code_same_index() {
